==> apache-kylin-3.0.1-source-release.zip: apache-kylin-3.0.1/stream-receiver/src/main/java/org/apache/kylin/stream/server/retention/RetentionPolicyInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.apache.kylin.stream.server.retention;

import java.util.Map;

import com.google.common.collect.Maps;

/**
 * Retention policy for local segment cache
 */
public class RetentionPolicyInfo {
    /**
     * outdated data will be dropped
     */
    public static final String PURGE_POLICY = "purge";
    /**
     * when data become immutable, it will be presisted remotely
     */
    public static final String FULL_BUILD_POLICY = "fullBuild";

    private String name;
    private Map<String, String> properties = Maps.newHashMap();

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Map<String, String> getProperties() {
        return properties;
    }

    public void setProperties(Map<String, String> properties) {
        this.properties = properties;
    }

    public void addProperty(String name, String value) {
        properties.put(name, value);
    }
}

==> apache-kylin-3.1.3-source-release.zip: apache-kylin-3.1.3/stream-receiver/src/main/java/org/apache/kylin/stream/server/retention/RetentionPolicyInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.apache.kylin.stream.server.retention;

import java.util.Map;

import org.apache.kylin.shaded.com.google.common.collect.Maps;

/**
 * Retention policy for local segment cache
 */
public class RetentionPolicyInfo {
    /**
     * outdated data will be dropped
     */
    public static final String PURGE_POLICY = "purge";
    /**
     * when data become immutable, it will be presisted remotely
     */
    public static final String FULL_BUILD_POLICY = "fullBuild";

    private String name;
    private Map<String, String> properties = Maps.newHashMap();

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Map<String, String> getProperties() {
        return properties;
    }

    public void setProperties(Map<String, String> properties) {
        this.properties = properties;
    }

    public void addProperty(String name, String value) {
        properties.put(name, value);
    }
}
